remm 2003/07/25 09:43:12
Modified: catalina/src/share/org/apache/catalina/startup
HostConfig.java
Log:
- Don't redeploy when a context file is added, and the context wasn't deployed
with the auto deployer.
Revision Changes Path
1.19 +14 -8
jakarta-tomcat-catalina/catalina/src/share/org/apache/catalina/startup/HostConfig.java
Index: HostConfig.java
===================================================================
RCS file:
/home/cvs/jakarta-tomcat-catalina/catalina/src/share/org/apache/catalina/startup/HostConfig.java,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -r1.18 -r1.19
--- HostConfig.java 25 Jul 2003 13:57:30 -0000 1.18
+++ HostConfig.java 25 Jul 2003 16:43:12 -0000 1.19
@@ -509,10 +509,16 @@
log.debug(sm.getString("hostConfig.deployDescriptor", files[i]));
try {
if (host.findChild(contextPath) != null) {
- // If this is a newly added context file and
- // it overrides a context with a simple path,
- // undeploy the context
- ((Deployer) host).remove(contextPath);
+ if ((deployed.contains(file))
+ || (deployed.contains(file + ".war"))) {
+ // If this is a newly added context file and
+ // it overrides a context with a simple path,
+ // that was previously deployed by the auto
+ // deployer, undeploy the context
+ ((Deployer) host).remove(contextPath);
+ } else {
+ continue;
+ }
}
URL config =
new URL("file", null, dir.getCanonicalPath());
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]